EXPORTS
	??0CRemConInterfaceBase@@IAE@VTUid@@IAAVCRemConInterfaceSelector@@W4TRemConClientType@@@Z @ 1 NONAME ; CRemConInterfaceBase::CRemConInterfaceBase(class TUid, unsigned int, class CRemConInterfaceSelector &, enum TRemConClientType)
	??1CRemConInterfaceBase@@UAE@XZ @ 2 NONAME ; CRemConInterfaceBase::~CRemConInterfaceBase(void)
	??1CRemConInterfaceSelector@@UAE@XZ @ 3 NONAME ; CRemConInterfaceSelector::~CRemConInterfaceSelector(void)
	?BaseConstructL@CRemConInterfaceBase@@IAEXXZ @ 4 NONAME ; void CRemConInterfaceBase::BaseConstructL(void)
	?Cancel@CRemConInterfaceBase@@QAEHXZ @ 5 NONAME ; int CRemConInterfaceBase::Cancel(void)
	?ConnectBearer@CRemConInterfaceSelector@@QAEXAAVTRequestStatus@@@Z @ 6 NONAME ; void CRemConInterfaceSelector::ConnectBearer(class TRequestStatus &)
	?ConnectBearerCancel@CRemConInterfaceSelector@@QAEHXZ @ 7 NONAME ; int CRemConInterfaceSelector::ConnectBearerCancel(void)
	?DisconnectBearer@CRemConInterfaceSelector@@QAEXAAVTRequestStatus@@@Z @ 8 NONAME ; void CRemConInterfaceSelector::DisconnectBearer(class TRequestStatus &)
	?DisconnectBearerCancel@CRemConInterfaceSelector@@QAEHXZ @ 9 NONAME ; int CRemConInterfaceSelector::DisconnectBearerCancel(void)
	?GetConnections@CRemConInterfaceSelector@@QAEHAAV?$TSglQue@VTRemConAddress@@@@@Z @ 10 NONAME ; int CRemConInterfaceSelector::GetConnections(class TSglQue<class TRemConAddress> &)
	?GoConnectionOrientedL@CRemConInterfaceSelector@@QAEXABVTRemConAddress@@@Z @ 11 NONAME ; void CRemConInterfaceSelector::GoConnectionOrientedL(class TRemConAddress const &)
	?GoConnectionlessL@CRemConInterfaceSelector@@QAEXXZ @ 12 NONAME ; void CRemConInterfaceSelector::GoConnectionlessL(void)
	?InterfaceSelector@CRemConInterfaceBase@@IAEAAVCRemConInterfaceSelector@@XZ @ 13 NONAME ; class CRemConInterfaceSelector & CRemConInterfaceBase::InterfaceSelector(void)
	?NewL@CRemConInterfaceSelector@@SAPAV1@XZ @ 14 NONAME ; class CRemConInterfaceSelector * CRemConInterfaceSelector::NewL(void)
	?NotifyConnectionsChange@CRemConInterfaceSelector@@QAEXAAVTRequestStatus@@@Z @ 15 NONAME ; void CRemConInterfaceSelector::NotifyConnectionsChange(class TRequestStatus &)
	?NotifyConnectionsChangeCancel@CRemConInterfaceSelector@@QAEHXZ @ 16 NONAME ; int CRemConInterfaceSelector::NotifyConnectionsChangeCancel(void)
	?OpenControllerL@CRemConInterfaceSelector@@QAEXXZ @ 17 NONAME ; void CRemConInterfaceSelector::OpenControllerL(void)
	?OpenTargetL@CRemConInterfaceSelector@@QAEXXZ @ 18 NONAME ; void CRemConInterfaceSelector::OpenTargetL(void)
	?RegisterInterfaceL@CRemConInterfaceSelector@@QAEXAAVCRemConInterfaceBase@@@Z @ 19 NONAME ; void CRemConInterfaceSelector::RegisterInterfaceL(class CRemConInterfaceBase &)
	?Send@CRemConInterfaceSelector@@QAEXAAVTRequestStatus@@VTUid@@IAAIW4TRemConMessageType@@ABVTDesC8@@@Z @ 20 NONAME ; void CRemConInterfaceSelector::Send(class TRequestStatus &, class TUid, unsigned int, unsigned int &, enum TRemConMessageType, class TDesC8 const &)
	?SendCancel@CRemConInterfaceSelector@@QAEHW4TRemConMessageType@@@Z @ 21 NONAME ; int CRemConInterfaceSelector::SendCancel(enum TRemConMessageType)
	?RegisterErrorObserver@CRemConInterfaceSelector@@QAEXPAVMRemConErrorObserver@@@Z @ 22 NONAME ; void CRemConInterfaceSelector::RegisterErrorObserver(class MRemConErrorObserver *)
	?ControllerOpened@CRemConInterfaceSelector@@QBEHXZ @ 23 NONAME ; int CRemConInterfaceSelector::ControllerOpened(void) const
	?TargetOpened@CRemConInterfaceSelector@@QBEHXZ @ 24 NONAME ; int CRemConInterfaceSelector::TargetOpened(void) const
	?SendUnreliable@CRemConInterfaceSelector@@QAEHVTUid@@IW4TRemConMessageType@@ABVTDesC8@@@Z @ 25 NONAME ; int CRemConInterfaceSelector::SendUnreliable(class TUid, unsigned int, enum TRemConMessageType, class TDesC8 const &)
	?Send@CRemConInterfaceSelector@@QAEXAAVTRequestStatus@@VTUid@@IAAIW4TRemConMessageType@@W4TRemConMessageSubType@@ABVTDesC8@@@Z @ 26 NONAME ; void CRemConInterfaceSelector::Send(class TRequestStatus &, class TUid, unsigned int, unsigned int &, enum TRemConMessageType, enum TRemConMessageSubType, class TDesC8 const &)
	?SendUnreliable@CRemConInterfaceSelector@@QAEHVTUid@@IW4TRemConMessageType@@W4TRemConMessageSubType@@ABVTDesC8@@@Z @ 27 NONAME ; int CRemConInterfaceSelector::SendUnreliable(class TUid, unsigned int, enum TRemConMessageType, enum TRemConMessageSubType, class TDesC8 const &)
	?OpenTargetL@CRemConInterfaceSelector@@QAEXW4TPlayerType@@W4TPlayerSubType@@ABVTDesC8@@@Z @ 28 NONAME ; void CRemConInterfaceSelector::OpenTargetL(enum TPlayerType, enum TPlayerSubType, class TDesC8 const &)
	?Open@RRemConInterfaceFeatures@@QAEHXZ @ 29 NONAME ; int RRemConInterfaceFeatures::Open(void)
	?BaseConstructL@CRemConInterfaceBase@@IAEXAAVRRemConInterfaceFeatures@@@Z @ 30 NONAME ; void CRemConInterfaceBase::BaseConstructL(class RRemConInterfaceFeatures &)
	?Close@RRemConInterfaceFeatures@@QAEXXZ @ 31 NONAME ; void RRemConInterfaceFeatures::Close(void)
	?AddOperationL@RRemConInterfaceFeatures@@QAEXI@Z @ 32 NONAME ; void RRemConInterfaceFeatures::AddOperationL(unsigned int)
	?SendBulk@CRemConInterfaceSelector@@QAEXAAVTRequestStatus@@VTUid@@IABVTDesC8@@@Z @ 33 NONAME ; void CRemConInterfaceSelector::SendBulk(class TRequestStatus &, class TUid, unsigned int, class TDesC8 const &)
	?SendBulkUnreliable@CRemConInterfaceSelector@@QAEHVTUid@@IABVTDesC8@@@Z @ 34 NONAME ; int CRemConInterfaceSelector::SendBulkUnreliable(class TUid, unsigned int, class TDesC8 const &)
	?SendBulkCancel@CRemConInterfaceSelector@@QAEHXZ @ 35 NONAME ; int CRemConInterfaceSelector::SendBulkCancel(void)
	?SendNotify@CRemConInterfaceSelector@@QAEXAAVTRequestStatus@@VTUid@@IW4TRemConMessageType@@W4TRemConMessageSubType@@ABVTDesC8@@@Z @ 36 NONAME ; void CRemConInterfaceSelector::SendNotify(class TRequestStatus &, class TUid, unsigned int, enum TRemConMessageType, enum TRemConMessageSubType, class TDesC8 const &)
	?BaseConstructL@CRemConInterfaceBase@@IAEXAAVRRemConInterfaceFeatures@@H@Z @ 37 NONAME ; void CRemConInterfaceBase::BaseConstructL(class RRemConInterfaceFeatures &, int)

